@@ -49,30 +49,41 @@ def _get_figure_and_axis():
 
 def _get_figures_and_axes(n, m):
     figs, axes = plt.subplots(n, m)
-    for i in range(n):
-        for j in range(m):
-            axes[i, j].spines["left"].set_position("zero")
-            axes[i, j].spines["right"].set_color("none")
-            axes[i, j].spines["bottom"].set_position("zero")
-            axes[i, j].spines["top"].set_color("none")
+    for ax in axes.flat:
+        ax.spines["left"].set_position("zero")
+        ax.spines["right"].set_color("none")
+        ax.spines["bottom"].set_position("zero")
+        ax.spines["top"].set_color("none")
 
-            axes[i, j].plot(
-                1,
-                0,
-                ">k",
-                transform=axes[i, j].get_yaxis_transform(),
-                clip_on=False,
-            )
-            axes[i, j].plot(
-                0,
-                1,
-                "^k",
-                transform=axes[i, j].get_xaxis_transform(),
-                clip_on=False,
-            )
+        ax.plot(1, 0, ">k", transform=ax.get_yaxis_transform(), clip_on=False)
+        ax.plot(0, 1, "^k", transform=ax.get_xaxis_transform(), clip_on=False)
 
-            axes[i, j].set_xlabel(r"$x$", fontsize=16, loc="right")
-            axes[i, j].set_ylabel(r"$y$", fontsize=16, loc="top", rotation="horizontal")
+        ax.set_xlabel(r"$x$", fontsize=16, loc="right")
+        ax.set_ylabel(r"$y$", fontsize=16, loc="top", rotation="horizontal")
+    # for i in range(n):
+    #     for j in range(m):
+    #         axes[i, j].spines["left"].set_position("zero")
+    #         axes[i, j].spines["right"].set_color("none")
+    #         axes[i, j].spines["bottom"].set_position("zero")
+    #         axes[i, j].spines["top"].set_color("none")
+
+    #         axes[i, j].plot(
+    #             1,
+    #             0,
+    #             ">k",
+    #             transform=axes[i, j].get_yaxis_transform(),
+    #             clip_on=False,
+    #         )
+    #         axes[i, j].plot(
+    #             0,
+    #             1,
+    #             "^k",
+    #             transform=axes[i, j].get_xaxis_transform(),
+    #             clip_on=False,
+    #         )
+
+    #         axes[i, j].set_xlabel(r"$x$", fontsize=16, loc="right")
+    #         axes[i, j].set_ylabel(r"$y$", fontsize=16, loc="top", rotation="horizontal")
 
     return figs, axes
 
@@ -106,13 +117,20 @@ def _set_multiple_ticks(xmin, xmax, ymin, ymax, xstep, ystep, axes):
 
     yticklabels = [f"${i}$" for i in yticks]
 
-    for i in axes.shape[0]:
-        for j in axes.shape[1]:
-            axes[i, j].set_xticks(xticks)
-            axes[i, j].set_xticklabels(xticklabels, fontsize=16)
+    for ax in axes.flat:
+        ax.set_xticks(xticks)
+        ax.set_xticklabels(xticklabels, fontsize=16)
 
-            axes[i, j].set_yticks(yticks)
-            axes[i, j].set_yticklabels(yticklabels, fontsize=16)
+        ax.set_yticks(yticks)
+        ax.set_yticklabels(yticklabels, fontsize=16)
+
+    # for i in axes.shape[0]:
+    #     for j in axes.shape[1]:
+    #         axes[i, j].set_xticks(xticks)
+    #         axes[i, j].set_xticklabels(xticklabels, fontsize=16)
+
+    #         axes[i, j].set_yticks(yticks)
+    #         axes[i, j].set_yticklabels(yticklabels, fontsize=16)
 
     return axes
 
@@ -211,11 +229,9 @@ def multiplot(
             axes=axes,
         )
     else:
-        for i in axes.shape[0]:
-            for j in axes.shape[1]:
-                ax = axes[i, j]
-                ax.set_xticks([])
-                ax.set_yticks([])
+        for ax in axes.flat:
+            ax.set_xticks([])
+            ax.set_yticks([])
 
     x = np.linspace(xmin, xmax, int(2**12))
 
